X-Git-Url: https://git.rapsys.eu/packbundle/blobdiff_plain/ce4ef48d51a312fa5f854e91f3825a699d9325e8..380623890b4880b1ea107945f7a3b9b59409081e:/RapsysPackBundle.php

diff --git a/RapsysPackBundle.php b/RapsysPackBundle.php
index ca879af..4ad24d4 100644
--- a/RapsysPackBundle.php
+++ b/RapsysPackBundle.php
@@ -11,19 +11,29 @@
 
 namespace Rapsys\PackBundle;
 
-use Symfony\Component\DependencyInjection\Container;
+use Symfony\Component\DependencyInjection\Extension\ExtensionInterface;
 use Symfony\Component\HttpKernel\Bundle\Bundle;
 
+use Rapsys\PackBundle\DependencyInjection\RapsysPackExtension;
+
 /**
  * {@inheritdoc}
  */
 class RapsysPackBundle extends Bundle {
+	/**
+	 * {@inheritdoc}
+	 */
+	public function getContainerExtension(): ?ExtensionInterface {
+		//Return created container extension
+		return $this->createContainerExtension();
+	}
+
 	/**
 	 * Return bundle alias
 	 *
 	 * @return string The bundle alias
 	 */
-    public function getAlias(): string {
+	public static function getAlias(): string {
 		//With namespace
 		if ($npos = strrpos(static::class, '\\')) {
 			//Set name pos
@@ -43,7 +53,17 @@ class RapsysPackBundle extends Bundle {
 			$bpos = strlen(static::class) - $npos;
 		}
 
-		//Return underscored lowercase bundle alias
-		return Container::underscore(substr(static::class, $npos, $bpos));
-    }
+		//Return lowercase bundle alias
+		return strtolower(substr(static::class, $npos, $bpos));
+	}
+
+	/**
+	 * Return bundle version
+	 *
+	 * @return string The bundle version
+	 */
+	public static function getVersion(): string {
+		//Return version
+		return '0.4.0';
+	}
 }